# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# A noarch-turned-arch package should not have debuginfo
%global debug_package %{nil}

# Fix up RPM/CPAN versioning incompatibilities
%global cpanversion 7.17
%global rpmversion 7.17

# Convenient function for distro testing
%define fedora_rhel_later_than() %([ \\( "%{__distinit}" = "fc" -a %{__distvers} -gt %1 \\) -o \\( "%{__distinit}" = "rhel" -a %{__distvers} -gt %2 \\) ] && echo 1 || echo 0)

# perl-Tk FTBFS in Fedora 39 (s390x only: Bug #2222638)
%define perl_tk_broken %([ \\( "%{__distinit}" = "fc" -a %{__distvers} -gt 38 \\) -o \\( "%{__distinit}" = "rhel" -a %{__distvers} -gt 9 \\) ] && echo 1 || echo 0)

# Use weak dependencies where available
%global have_weak_deps 0%{?fedora} > 20 || 0%{?rhel} > 7

Name:		perl-AnyEvent
Version:	%{rpmversion}
Release:	16.%{__distinit}%{__distvers}
Summary:	Framework for multiple event loops
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/AnyEvent
Source0:	https://cpan.metacpan.org/modules/by-module/AnyEvent/AnyEvent-%{cpanversion}.tar.gz
# Build requirements
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Canary::Stability)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module requirements
BuildRequires:	perl(B)
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Guard)
BuildRequires:	perl(integer)
BuildRequires:	perl(JSON::XS)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(overload)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Socket)
BuildRequires:	perl(Storable)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sys::Syslog)
BuildRequires:	perl(Task::Weaken)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(Unicode::Normalize)
# Test suite requirements
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Net::SSLeay) >= 1.33
BuildRequires:	perl(Test::More)
BuildRequires:	perl(utf8)
BuildRequires:	perl(warnings)
# Event loop testing (Cocoa, FLTK and UV are not in Fedora/EPEL)
# EV → AnyEvent
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(EV) >= 4.00
%endif
BuildRequires:	perl(Event)
BuildRequires:	perl(Glib) >= 1.210
# AnyEvent::AIO requires AnyEvent itself
# AnyEvent::IO::IOAIO event loop requires IO::AIO and AnyEvent::AIO
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(AnyEvent::AIO)
BuildRequires:	perl(IO::AIO) >= 4.13
%endif
%if %fedora_rhel_later_than 19 8
BuildRequires:	perl(IO::Async::Loop) >= 0.33
%endif
BuildRequires:	perl(POE) >= 1.312
%if !%{perl_tk_broken}
BuildRequires:	perl(Tk)
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(File::Temp)
%if %{have_weak_deps}
# Optional but recommended
Recommends:	perl(Guard)
Recommends:	perl(Storable)
Recommends:	perl(Sys::Syslog)
Recommends:	perl(Task::Weaken)
Recommends:	perl(Unicode::Normalize)
# Heavier optional modules
Suggests:	perl(CBOR::XS)
Suggests:	perl(Coro)
Suggests:	perl(Coro::Debug)
Suggests:	perl(JSON::XS)
Suggests:	perl(Net::SSLeay) >= 1.33
%else
Requires:	perl(Guard)
Requires:	perl(Storable)
Requires:	perl(Sys::Syslog)
Requires:	perl(Task::Weaken)
Requires:	perl(Unicode::Normalize)
%endif

# Optional dependencies we don't want to require
%global optional_deps ^perl[(](AnyEvent::AIO|Cocoa::EventLoop|EV|Event|Event::Lib|FLTK|Glib|IO::AIO|IO::Async::Loop|Irssi|Net::SSLeay|POE|Qt|Qt::isa|Qt::slots|Tk|UV)[)]

# Don't include optional dependencies
%global __requires_exclude %{optional_deps}

# Filter unversioned and bogus provides
%global __provides_exclude ^perl[(](AnyEvent|DB)[)]$

%description
AnyEvent provides an identical interface to multiple event loops. This allows
module authors to utilize an event loop without forcing module users to use the
same event loop (as multiple event loops cannot coexist peacefully at any one
time).

%prep
%setup -q -n AnyEvent-%{cpanversion}

%build
PERL_CANARY_STABILITY_NOPROMPT=1 perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test PERL_ANYEVENT_LOOP_TESTS=1 PERL_ANYEVENT_NET_TESTS=0

%files
%license COPYING
%doc Changes README
%{perl_vendorarch}/AE.pm
%{perl_vendorarch}/AnyEvent.pm
%{perl_vendorarch}/AnyEvent/
%{_mandir}/man3/AE.3*
%{_mandir}/man3/AnyEvent.3*
%{_mandir}/man3/AnyEvent::DNS.3*
%{_mandir}/man3/AnyEvent::Debug.3*
%{_mandir}/man3/AnyEvent::FAQ.3*
%{_mandir}/man3/AnyEvent::Handle.3*
%{_mandir}/man3/AnyEvent::Impl::Cocoa.3*
%{_mandir}/man3/AnyEvent::Impl::EV.3*
%{_mandir}/man3/AnyEvent::Impl::Event.3*
%{_mandir}/man3/AnyEvent::Impl::EventLib.3*
%{_mandir}/man3/AnyEvent::Impl::FLTK.3*
%{_mandir}/man3/AnyEvent::Impl::Glib.3*
%{_mandir}/man3/AnyEvent::Impl::IOAsync.3*
%{_mandir}/man3/AnyEvent::Impl::Irssi.3*
%{_mandir}/man3/AnyEvent::Impl::POE.3*
%{_mandir}/man3/AnyEvent::Impl::Perl.3*
%{_mandir}/man3/AnyEvent::Impl::Qt.3*
%{_mandir}/man3/AnyEvent::Impl::Tk.3*
%{_mandir}/man3/AnyEvent::Impl::UV.3*
%{_mandir}/man3/AnyEvent::Intro.3*
%{_mandir}/man3/AnyEvent::IO.3*
%{_mandir}/man3/AnyEvent::IO::IOAIO.3*
%{_mandir}/man3/AnyEvent::IO::Perl.3*
%{_mandir}/man3/AnyEvent::Log.3*
%{_mandir}/man3/AnyEvent::Loop.3*
%{_mandir}/man3/AnyEvent::Socket.3*
%{_mandir}/man3/AnyEvent::Strict.3*
%{_mandir}/man3/AnyEvent::TLS.3*
%{_mandir}/man3/AnyEvent::Util.3*

%changelog
* Thu Jul 13 2023 Paul Howarth <paul@city-fan.org> - 7.17-16
- Perl 5.38 rebuild

* Tue Mar  7 2023 Paul Howarth <paul@city-fan.org> - 7.17-15
- Use SPDX-format license tag

* Thu Jun  2 2022 Paul Howarth <paul@city-fan.org> - 7.17-11
- Perl 5.36 rebuild

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 7.17-8
- Perl 5.34 rebuild

* Sat Jun 27 2020 Paul Howarth <paul@city-fan.org> - 7.17-4
- Perl 5.32 rebuild

* Wed Sep 18 2019 Paul Howarth <paul@city-fan.org> - 7.17-1
- Update to 7.17
  - Work around antique openssl version in RHEL-7 by formatting dh parameters
    differently
  - Add t/13_weaken.t
- Drop previous dh parameter patch, no longer needed

* Sun Jul 21 2019 Paul Howarth <paul@city-fan.org> - 7.16-1
- Update to 7.16
  - Add ffdhe group dh parameters from RFC 7919, and use ffdhe3072 as new
    default, instead of schmorp1539
  - AnyEvent::Log did not re-assess logging status of AnyEvent::Log::loggers
    when contexts were changed with ->attach/detach/slaves, causing them not to
    log even though a recent attach should have caused them to log
  - Added some more logging configuration examples
  - Mention RFC 8482 in AnyEvent::DNS
- Add patch to use schmorp2048 as default dh parameters if we don't have at
  least OpenSSL 1.0.2, which is needed for support of the ffdhe group dh
  parameters (CPAN RT#130116)

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 7.15-3
- Perl 5.30 rebuild

* Tue Feb 26 2019 Paul Howarth <paul@city-fan.org> - 7.15-1
- Update to 7.15
  - INCOMPATIBLE CHANGE: AnyEvent::Handle's tls_detect documentation gave
    separate major and minor versions, while code passed only a single value;
    this version follows the documentation and now passes separate major and
    minor values
  - Work around Net::SSLeay not having been ported to openssl 1.1, but many
    distributions compiling it against openssl 1.1, which unfortunately
    succeeds and results in a very broken module
  - AnyEvent::DNS::dns_unpack now stores the original DNS packet in the __
    member, to allow decoding of undecodable resource records containing
    compressed domain names
  - AnyEvent::Socket::parse_ipv6 would NOT, as advertised, accept ipv4
    addresses; it now does and converts them to ipv4 mapped addresses
  - Support CAA records
  - Add freenom and cloudflare nameservers as DNS fallback
  - AnyEvent::Strict would not properly ward against io watchers on files when
    the handle passed was a file descriptor
  - Document "internal" variables used by the DNS en-/decoder to allow
    enterprising users to extend them in a semi-official way

* Sat Jun 30 2018 Paul Howarth <paul@city-fan.org> - 7.14-5
- Perl 5.28 rebuild

* Tue Aug  8 2017 Paul Howarth <paul@city-fan.org> - 7.14-3
- BR: perl-generators, perl(Glib) and perl(Tk) unconditionally
- BR: perl-interpreter rather than perl

* Sat Jun 24 2017 Paul Howarth <paul@city-fan.org> - 7.14-1
- Update to 7.14
  - Fix a crash bug in AnyEvent::Handle with openssl 1.1.0
  - AnyEvent::Handle->keepalive was documented (and defined) twice
  - AnyEvent::Socket::tcp_bind/tcp_server would immediately unlink a unix
    listening socket unless a guard is used; change this so that no clean-up
    will be performed unless a guard is used and document this more clearly
  - Make tcp_bind/tcp_server error messages more regular
  - Fix building on Perl without '.' in @INC
  - Add TCP_FASTOPEN/MSG_FASTOPEN and MSG_NOSIGNAL/MSG_MORE/MSG_DONTWAIT to
    constants
  - Update warnings to common::sense 3.74 standards

* Tue Jun 13 2017 Paul Howarth <paul@city-fan.org> - 7.13-8
- Fix building on Perl without '.' in @INC
- Disable network tests as our builders no longer allow network access
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Nov 25 2016 Paul Howarth <paul@city-fan.org> - 7.13-4
- Fix segfault in SSL handling that manifests on OpenSSL 1.1.0 x86_64
  (CPAN RT#118584, RHBZ#1390468)

* Tue Nov  1 2016 Paul Howarth <paul@city-fan.org> - 7.13-3
- Avoid interactive prompt during build (#1390463)
- For now, BuildConflict with perl-Net-SSLeay on Rawhide (#1390468)

* Mon Oct 17 2016 Paul Howarth <paul@city-fan.org> - 7.13-2
- Add some optional dependencies (#1385642)
- Work around SSL issues in Rawhide (possibly due to ongoing upgrade to
  OpenSSL 1.1.0)

* Mon Sep 19 2016 Paul Howarth <paul@city-fan.org> - 7.13-1
- Update to 7.13
  - Only call tlsext_host_name for non-empty common names
  - Log a (single) notice message if SNI is not supported
  - Upgrade to UTS-46:9.0.0 draft and switch to non-transitional behaviour
    (see also https://bugzilla.mozilla.org/show_bug.cgi?id=1218179)
  - It turns out that the UTS-46 IDNA testcase failures were indeed bugs in the
    testcases and the specification and not in the code - the post-9.0.0
    unicode files have all known problems fixed, so finally the AnyEvent IDNA
    implementation can pass the full IDNA testsuite - without needing a single
    fix
  - Guarantee (and document) that condvar callbacks will be removed on
    invocation - important to avoid circular references

* Tue Aug  2 2016 Paul Howarth <paul@city-fan.org> - 7.12-4
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete
- Prefer %%global over %%define

* Thu Jan 28 2016 Paul Howarth <paul@city-fan.org> - 7.12-1
- Update to 7.12
  - Use common name as hostname for TLS connects, if Net::SSLeay supports SNI
  - Fix documentation of tls_autostart read type in AnyEvent::Handle

* Mon Aug 31 2015 Paul Howarth <paul@city-fan.org> - 7.11-2
- BR:/R: perl(Storable)

* Fri Jul 17 2015 Paul Howarth <paul@city-fan.org> - 7.11-1
- Update to 7.11
  - AnyEvent::Socket::parse_ipv6 could accept malformed ipv6 addresses (extra
    "::" at end and similar cases)
  - Add a more explicit warning to AnyEvent::Handle that it doesn't work on
    files; people keep getting confused
  - New function AnyEvent::Socket::tcp_bind
  - New functions AnyEvent::fh_block and AnyEvent::fh_unblock
  - Aligned ipv6 address formatting with RFC 5952 (by not shortening a single
    :0: to ::)
  - Added stability canary support

* Wed Jun 24 2015 Paul Howarth <paul@city-fan.org> - 7.09-4
- Perl 5.22 rebuild

* Sat May  2 2015 Paul Howarth <paul@city-fan.org> - 7.09-1
- Update to 7.09
  - AnyEvent::Debug called an internal function (AnyEvent::Log::ft) that was
    renamed to AnyEvent::Log:format_time, under its old name
  - Update AnyEvent::DNS fallback resolver addresses: it seems google
    effectively killed most other free dns resolvers, so remove them, but add
    Cable and Wireless (ecrc) since it was stable for 20 years or so, official
    or not, and there should be an alternative to google
  - perl5porters broke Windows error codes in 5.20, and mapped WSAEWOULDBLOCK
    on the (different) EWOULDBLOCK error code, and WSAEINPROGRESS into the
    incompatible ERINPROGRESS code (there may be others too); this version
    only works around the WSAEWOULDBLOCK issue, because I don't have a nice
    way to work around the WSAEINPROGRESS bug

* Wed Dec 10 2014 Paul Howarth <paul@city-fan.org> - 7.08-1
- Update to 7.08:
  - Work around a newly introduced bug in Socket 2.011 (an erroneous sun_length
    check)
  - AnyEvent::TLS didn't load (but refer to) AnyEvent::Socket
  - AnyEvent::Strict will now confess, not croak, in line with it being a
    development/debugging tool
  - Work around a number of libglib bugs (debug builds of libglib enforce
    certain undocumented behaviour patterns such as not being able to remove a
    child watch source after it has fired, which we will try to emulate to
    avoid "criticals"; what were they thinking?)
  - Mention json security issues in AnyEvent::Handle
  - Changed default DNS resolver "max_outstanding" value from 1 to 10, the
    latter being the intended value all along
  - Added new "AnyEvent::Impl::UV" interface module to the UV event lib

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 7.07-6
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Tue Dec 17 2013 Paul Howarth <paul@city-fan.org> - 7.07-1
- Update to 7.07:
  - The documentation for custom tls verify schemes was wrong; make it agree
    with the code
  - Added cbor read and write types to AnyEvent::Handle (using CBOR::XS)
  - Work around an API change in openssl that could cause wrong tls connection
    aborts, likely on windows only
  - Calling AnyEvent->now_update with AnyEvent::Impl::Perl caused an endless
    loop
  - Add tlsv1_1 and tlsv1_2 protocols to AnyEvent::TLS
  - Document AnyEvent::Impl::IOAsync::set_loop and
    $AnyEvent::Impl::IOAsync::LOOP; though only documented now, this
    functionality has always been available
  - Force a toplevel domain name in t/81_hosts.t
  - Document that AnyEvent::Log uses AnyEvent::IO
  - Warn about AnyEvent::Filesys::Notify performance
  - Praise the joys of AnyEvent::Fork::*
  - Time for an =encoding directive
  - No longer use JSON to create a default json coder; use JSON::XS or JSON::PP
    directly

* Wed Aug 21 2013 Paul Howarth <paul@city-fan.org> - 7.05-1
- Update to 7.05:
   - uts46data.pl couldn't be found due to wrong naming of the file
   - Handle lone \015's properly in AE::Handle's default line read
   - Untaint IP addresses found in /etc/hosts
   - The memleak fix in 7.03 caused resolving via /etc/hosts always to fail on
     first use
   - Expose AnyEvent::Log::format_time, and allow users to redefine it
   - Expose AnyEvent::Log::default_format, and allow redefinition
   - Expose AnyEvent::Log::fatal_exit, to allow redefinition
   - AnyEvent::Debug shell can now run coro shell commands, if available
   - t/63* tests were wrongly in MANIFEST
   - kernel.org's finger server went MIA, switch to freebsd.org and icculus.org
   - Clarify that IO::AIO and AnyEvent::AIO are needed for AnyEvent::IO to
     function asynchronously
   - Hard-disable $^W in most tests; it generates too much garbage output
   - Use a (hopefully) more future-proof method to emulate common::sense
   - Upgrade to UTS-46:6.2.0
   - Switch to INSTLIB from INSTLIBDIR, as INSTLIBDIR was wrongly documented;
     should not affect anything
- Don't BR: perl(Event::Lib) as that back-end is not tested
- BR: perl(IO::Async::Loop) ≥ 0.33 for the test suite now that a new enough
  version is available in Fedora
- BR: perl(File::Temp) for the test suite

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 7.04-3
- Perl 5.18 rebuild

* Thu Nov 15 2012 Paul Howarth <paul@city-fan.org> - 7.04-1
- Update to 7.04:
  - AnyEvent::Socket::inet_aton did not work when DNS resolution was used to
    find the addresses
  - Fix a memory leak in the /etc/hosts lookup code when hosts don't resolve
    and are not in hosts

* Tue Aug 21 2012 Paul Howarth <paul@city-fan.org> - 7.02-1
- Update to 7.02:
  - AnyEvent::Util::run_cmd could block indefinitely
  - Verified that AnyEvent::Socket follows RFC5952
  - Try to parse "ADDR#PORT" in addition to "ADDR PORT"

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 7.01-3
- Perl 5.16 post-bootstrap rebuild

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 7.01-2
- Perl 5.16 rebuild

* Sun May 13 2012 Paul Howarth <paul@city-fan.org> - 7.01-1
- Update to 7.01:
  - Fail with EPROTO in AnyEvent::Handle when TLS is requested but not
    available, instead of throwing an exception
  - Use File::Spec to get the tmpdir in t/*, to avoid needless failures on
    (most, not mine :) windows boxes
  - New handle read types: tls_detect and tls_autostart
- BR: perl(File::Spec)
- Avoid Event::Lib prior to EL-7/F-14 as t/63_eventlib_05_dns.t reliably fails
  on F-13/i686; newer libevent needed

* Fri Apr 13 2012 Paul Howarth <paul@city-fan.org> - 7.0-1
- Update to 7.0:
  - Child watchers are broken in POE 1.352 (also many earlier versions) and
    there seems to be no way to work around it, as POE itself is inherently
    racy: document this regression and add a delay in t/68_poe_03_child.t for
    the time being
  - New module AnyEvent::IO, a frontend to either a pure-perl synchronous I/O
    implementation (AnyEvent::IO::Perl), or to the asynchronous I/O extension
    IO::AIO (AnyEvent::IO::IOAIO)
  - Load /etc/hosts only when DNS has no answer
  - stat /etc/hosts on every access and reload it if it changed
  - Load /etc/hosts via AnyEvent::IO - potentially asynchronous
  - Fix a buggy croak in the dh parameter reading in AnyEvent::TLS
  - AnyEvent::Log log_to_file and log_to_path now use AnyEvent::IO; as a side
    effect, they now use true appending as opposed to libc appending, and the
    file might not have been opened when the function returns
  - The default logging level was not properly documented in a variety of
    places
  - Updated uts46data.pl for unicode 6.1.0
  - Made log messages generated by AnyEvent submodules not include the package
    name any longer, as it will be logged by default already
  - Upgrade to the trick used by common-sense 3.5 to work around extra warning
    torture/breakage under perl 5.15.x
  - Log messages by anyevent are now ucfirst, are usually full sentences and no
    longer include the package name
  - The storable read type would sometimes throw an exception instead of
    causing EBADMSG
  - Work around a bug in openssl 1.0.1, which enforces a minimum rsa keysize
- Drop TLS patch, now included in upstream release
- BR: perl(AnyEvent::AIO) and perl(IO::AIO) (except when bootstrapping) to test
  the new AnyEvent::IO::IOAIO module
- Update dependency filter to include optional perl(AnyEvent::AIO) and
  perl(IO::AIO) dependencies
- Don't BR: perl(Event::Lib) prior to F-12 as the new test
  t/63_eventlib_09_multi.t fails subtest 7 for reasons as yet unknown

* Thu Apr  5 2012 Paul Howarth <paul@city-fan.org> - 6.14-4
- Add upstream patch for TLS test, with longer key for OpenSSL 1.0.1
  compatibility (CPAN RT#75343)
- BR: Perl core modules that might be dual-lived
- Don't need to remove empty directories from buildroot
- Drop compatibility with old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}

* Fri Feb 10 2012 Paul Howarth <paul@city-fan.org> - 6.14-3
- Don't BR: perl(EV) if we're bootstrapping

* Wed Feb  1 2012 Paul Howarth <paul@city-fan.org> - 6.14-2
- Reinstate perl(Tk) as a buildreq now that it can actually load

* Tue Jan 31 2012 Paul Howarth <paul@city-fan.org> - 6.14-1
- Update to 6.14:
  - AnyEvent::Impl::Tk was broken due to a mysterious "die" inside, probably an
    editing mistake

* Thu Jan 12 2012 Paul Howarth <paul@city-fan.org> - 6.13-1
- Update to 6.13:
  - AnyEvent::Util::fork_call checked for POSIX availability in the wrong way,
    causing it to fail if POSIX wasn't loaded already
  - AnyEvent::Handle::push_read (line => ...) did pass $1 directly, so
    regex-matching inside the callback would change the parameter, despite
    $1 being dynamically scoped per-block; this perl bug is now being worked
    around

* Mon Dec 12 2011 Paul Howarth <paul@city-fan.org> - 6.12-1
- Update to 6.12:
  - $! was clobbered by subsequent calls in tcp_connect, due to the postpone
    not saving/restoring it

* Tue Nov 22 2011 Paul Howarth <paul@city-fan.org> - 6.11-1
- Update to 6.11:
  - Tk cannot create windows when tainted unless you set a title, so set a
    dummy title for AnyEvent's dummy mainwindow
  - Escape any non-printable/non-ascii characters when stringifying backtraces
  - Log the reason loading an interface module fails to load at level debug
- Drop perl(Tk) buildreq as the Tk module just doesn't seem to want to load

* Tue Oct  4 2011 Paul Howarth <paul@city-fan.org> - 6.10-1
- Update to 6.1:
  - INCOMPATIBLE CHANGE: the default log level is now "4" (error and above),
    and some messages inside AnyEvent have been elevated to higher log levels
    to print by default
  - AnyEvent::log, unlike AnyEvent::Log::log, did not always exit on fatal
  - Work around yet another signal race bug, newly introduced by POE
  - Add google public ipv6 dns as fallback servers, so AE::DNS can finally
    support ipv6-only operation even with defaults (also use ::1 instead of
    127.0.0.1)
  - Give better guidelines on how to choose a logging level
  - AnyEvent::Log can now cap (limit) log message priority by context
  - AE::log will now save and restore $! and $@, so callers don't have to
  - AE::Strict now checks that registered fds are still valid at regular
    intervals
  - Skip frequently called 'require' calls if the module appears loaded
  - Increase signal latency test timer considerably for poor little OSX, which
    can't be bothered with basic POSIX functionality such as signal delivery
  - Mention some debugging aides in the tutorial
  - New environment variable PERL_ANYEVENT_MAX_SIGNAL_LATENCY
  - Private (%%namespace) log contexts in PERL_ANYEVENT_LOG now have the name
    of the context as title
  - AnyEvent::Strict would not restore read-write access to $_ when a callback
    died - this is a user bug, but since AE::Strict exists to help dbeugging...
  - Detect the extremely evil IO::Async::Loop::AnyEvent module and refuse to
    work with it - the author is well aware of the issues but refuses to fix
    them; this extreme step has been taken because the module actively attacks
    the goals of AnyEvent and makes it harder for module authors to use
    AnyEvent
- BR: perl(Carp)

* Fri Aug 26 2011 Paul Howarth <paul@city-fan.org> - 6.02-1
- Update to 6.02:
  - log_to_syslog now accepts facility strings.
  - log_to_syslog would not allow facilities - "$facility|$level" *literally*
    means that string
  - The CPAN parser got confused and thought we provide Sys::Syslog; try to
    work around it
  - Rename AnyEvent::Impl::FLTK2 to FLTK

* Fri Aug 26 2011 Paul Howarth <paul@city-fan.org> - 6.01-1
- Update to 6.01:
  - INCOMPATIBLE CHANGE: Verbosity levels have been redefined; see AnyEvent
    (PERL_ANYEVENT_VERBOSE) and AnyEvent::Log for details
  - New function: AnyEvent::log
  - New module: AnyEvent::Log, for simple logging needs
  - New env variable, PERL_ANYEVENT_LOG, for fine-grained logging config
  - New env variable, PERL_ANYEVENT_HOSTS, to override the place where the
    /etc/hosts file can be found
  - An empty PERL_ANYEVENT_RESOLV_CONF now selects the default configuration
  - Environment variables can now be specified using AE_xyz instead of
    PERL_ANYEVENT_xyz, subject to some rules
  - Lots of new AnyEvent::Debug functionality
  - AnyEvent::Strict now checks for modifications of $_ by the callback (by
    setting it to readonly while executing the callback, if possible)
  - AnyEvent::Socket::resolve_sockaddr and all functions using it now support
    /etc/hosts overrides
  - Do not run event loop detection multiple times when programs call their
    cached copies of AnyEvent::detect
  - parse_hostport now accepts absolute paths as unix domain sockets
  - Suppress the idiotic warning inside POE by patching the POE::Kernel run
    flags instead of asking the user to jump through contortions
  - Add Task::Weaken as dependency (as recommends only at this time)
  - Replace PF_UNSPEC by 0, for good old Minix
- Drop now-redundant patch removing FLTK2 references
- Package manpages for AnyEvent::Impl::FLTK2 and AnyEvent::Log
- BR/R: perl(Task::Weaken)
- BR: perl(Net::SSLeay) unconditionally as although the test still emits a
  "Too late to run CHECK block" warning prior to perl 5.10, the test still
  passes
- BR: perl(Event::Lib), perl(Glib) ≥ 1.210, perl(POE) and perl(Tk) where
  possible (i.e. pull in from Fedora/EPEL)
- BR: perl(Time::HiRes)
- Filter bogus provide of perl(DB)

* Sun Aug 14 2011 Paul Howarth <paul@city-fan.org> - 6.0-1
- Update to 6.0:
  - INCOMPATIBLE CHANGE: AnyEvent::DNS resource records now include the TTL as
    fourth element - this affects ->resolve directly, and ->request and
    ->dns_unpack indirectly; convenience functions such as
    AnyEvent::DNS::{a,txt,mx,srv} are not affected, and neither is
    AnyEvent::Socket
  - INCOMPATIBLE CHANGE: backend authors now should not implement one_event or
    loop, but instead the AnyEvent::CondVar::_wait and _poll methods
  - DEPRECATION: please change
    "use AnyEvent::Impl::Perl" to "use AnyEvent::Loop" and
    "AnyEvent::Impl::Perl::loop" to "AnyEvent::Loop::run" in your programs, for
    future compatibility
  - Idle watcher emulation was borked
  - AnyEvent::Strict now checks the AE::xxx functions as well
  - Querying too-long domain names would barf deep inside AnyEvent::DNS; since
    this is hard to avoid for applications, AnyEvent:.DNS::request now checks
    for too-long domain names explicitly and passes an undef to the callback
    instead
  - Make AnyEvent::Util more robust against EINTR
  - New function: AnyEvent::postpone
  - New env variable, PERL_ANYEVENT_DEBUG_SHELL, to automatically start a debug
    shell
  - New env variable, PERL_ANYEVENT_DEBUG_WRAP, to automatically enable watcher
    instrumentation/wrapping (see AnyEvent::Debug::wrap)
  - IO::Async sometimes cancels the wrong timer when you call cancel_timer;
    invest extra overhead to work around this peculiar behaviour
  - Split the pure perl backend into a loop module and an impl module
    (AnyEvent::Loop and AnyEvent::Impl::Perl)
  - Some read types (regex, netstring, json, storable) could errornously keep
    an AE::Handle object alive on their own
  - Add more workarounds around child watcher bugs in IO::Async and (newly
    introduced) in POE
  - Use glib child watchers and try to work around its limitations, if possible
  - Add support for FLTK (fltk2) via AnyEvent::Impl::FLTK2
  - Many read types in AnyEvent::Handle would malfunction during transitions to
    TLS because of a "delete $self->{rbuf}"
  - Improve condvar blocking wait performance (probably only noticable with
    faster backends) and also make it easier for event loops that do not
    support blocking waits
  - PERL_ANYEVENT_MODEL now also allows full module names, although the
    usefulness of this feature is not yet clear
  - Add tests for all supported event loops, conditional on
    PERL_ANYEVENT_LOOP_TESTS
  - Add t/80_ssltext.t
  - No longer use AUTOLOAD for the initial loading (for no very good reason)
  - tcp_server now tries to unlink unix domain sockets when it gets destroyed
- Patch AnyEvent::Impl::FLTK2 out of Makefile.PL as upstream forgot to ship it
- Package new manpage for AnyEvent::Loop
- Add new buildreqs for tests: perl(EV), perl(Event), perl(Net::SSLeay)

* Sat Jun 25 2011 Paul Howarth <paul@city-fan.org> - 5.34-3
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Jun 25 2011 Paul Howarth <paul@city-fan.org> - 5.34-2
- Fix filter for rpm 4.9.x not to blow away versioned perl(AnyEvent) provide

* Thu May 12 2011 Paul Howarth <paul@city-fan.org> - 5.34-1
- Update to 5.34:
  - AnyEvent::Handle on_connect_error - do not try to destroy a handle object
    when it's already gone
  - Update idna algorithm(s) to UTS#46 version 6.0.0
  - Preserve trailing dot in idn_to_ascii - testsuite says to preserve, uts46
    says it's an error, and testsuite makes more sense
  - Remove leading dots in idn_to_ascii - testsuite says to remove, uts46 says
    it's an error, and testsuite makes more sense
  - Fixed a bug in idn ignored character processing
  - Passes the uts46 6.0.0 testsuite except for three cases which apparently
    are bugs in the testsuite itself
  - Passes the uts46 6.0.1 testsuite except for eleven cases which apparently
    are bugs in the testsuite itself
  - AE::TLS didn't support both cert_file and key at the same time, due to some
    copy&paste bug
  - Improve AE::Handle timeout documentation slightly
- Nobody else likes macros for commands
- Tidy up dependency filters
- Filter unversioned provide of perl(AnyEvent) if we have a versioned one

* Sun Jan 23 2011 Paul Howarth <paul@city-fan.org> - 5.31-1
- Update to 5.31:
  - Work around a POE bug where POE would first poll for new events and invoke
    handlers BEFORE handling the message queue
  - Fix parsing of "domain" statement in resolv.conf
  - stop_read now does just that in TLS mode; see its documentation for caveats
  - Update to common::sense 3.4 warning set
  - AE::Handle had a broken rbuf_max method and missing wbuf_max method
  - New experimental AE::Handle::resettls method

* Fri Jan 21 2011 Paul Howarth <paul@city-fan.org> - 5.30-1
- Import from Fedora
- Update to 5.3
- Filter optional dependencies more aggressively as this module is not
  intended to have any non-core dependencies by itself
- Module remains pure-perl but is now arch-specific as it includes
  arch-specific constants

* Tue Dec 14 2010 Marcela Maslanova <mmaslano@redhat.com> - 5.27-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Sun Aug 22 2010 Nicolas Chauvet <kwizart@gmail.com> - 5.27-1
- Update to 5.271 (rpm version : 5.27)

* Thu Apr 29 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 5.26-1
- Update to 5.261 (rpm version : 5.26)

* Thu Apr 29 2010 Marcela Maslanova <mmaslano@redhat.com> - 5.24-2
- Mass rebuild with perl-5.12.0

* Tue Jan 19 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 5.24-1
- Update to 5.24 (rpm version : 5.24)

* Mon Dec 7 2009 Nicolas Chauvet <kwizart@fedoraproject.org> - 5.22-1
- Update to 5.22 (rpm version : 5.22)

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 5.11-3
- Rebuild against perl 5.10.1

* Mon Aug 31 2009 kwizart < kwizart at gmail.com > - 5.11-2
- Update to 5.112 (rpm version : 5.11)

* Mon Jul 27 2009 kwizart < kwizart at gmail.com > - 4.870-1
- Update to 4.87 (rpm version : 4.870)
- Add more filter requires to workaround rhbz#512553

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.820-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 15 2009 kwizart < kwizart at gmail.com > - 4.820-1
- Update to 4.82 (rpm version : 4.820)

* Fri May 29 2009 kwizart < kwizart at gmail.com > - 4.410-1
- Update to 4.41 (rpm version : 4.410)

* Wed Apr 22 2009 kwizart < kwizart at gmail.com > - 4.352-1
- Update to 4.352 (rpm version : same)

* Fri Apr  3 2009 kwizart < kwizart at gmail.com > - 4.350-1
- Update to 4.35 (rpm version : 4.350)

* Thu Mar  5 2009 kwizart < kwizart at gmail.com > - 4.340-1
- Update to 4.34 (rpm version : 4.340)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.331-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jan 12 2009 kwizart < kwizart at gmail.com > - 4.331-1
- Update to 4.331 (rpm version : same)

* Fri Oct 17 2008 kwizart < kwizart at gmail.com > - 4.300-1
- Update to 4.3 (rpm version : 4.300)

* Tue Oct 14 2008 kwizart < kwizart at gmail.com > - 4.3-1
- Update to 4.3

* Mon Aug  4 2008 kwizart < kwizart at gmail.com > - 4.231-1
- Update to 4.231 (rpm version : match)

* Fri Jul 18 2008 kwizart < kwizart at gmail.com > - 4.220-1
- Update to 4.22 (rpm version : 4.220)

* Fri Jul 18 2008 kwizart < kwizart at gmail.com > - 4.21-1
- Update to 4.21

* Fri Jul  4 2008 kwizart < kwizart at gmail.com > - 4.161-1
- Update to 4.161

* Mon Jun 23 2008 kwizart < kwizart at gmail.com > - 4.152-1
- Update to 4.152

* Mon Jun  9 2008 kwizart < kwizart at gmail.com > - 4.151-1
- Update to 4.151

* Thu Jun  5 2008 kwizart < kwizart at gmail.com > - 4.13-1
- Update to 4.13

* Tue Jun  3 2008 kwizart < kwizart at gmail.com > - 4.12-1
- Update to 4.12

* Thu May 29 2008 kwizart < kwizart at gmail.com > - 4.1-1
- Update to 4.1

* Tue May 27 2008 kwizart < kwizart at gmail.com > - 3.5-1
- Update to 3.5

* Wed Apr 30 2008 kwizart < kwizart at gmail.com > - 3.3-1
- Initial package for Fedora
